==> print-manager-4.10.5.tar.xz: print-manager-4.10.5/add-printer/ChooseSerial.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CHOOSE_SERIAL_H
#define CHOOSE_SERIAL_H

#include "GenericPage.h"

#include <QRegExp>

namespace Ui {
    class ChooseSerial;
}

class ChooseSerial : public GenericPage
{
    Q_OBJECT
public:
    ChooseSerial(QWidget *parent = 0);
    ~ChooseSerial();

    void setValues(const QVariantHash &args);
    QVariantHash values() const;
    bool isValid() const;

public slots:
    void load();

private:
    Ui::ChooseSerial *ui;
    QRegExp m_rx;
    bool m_isValid;
};

#endif

==> print-manager-14.11.90.tar.xz: print-manager-14.11.90/add-printer/ChooseSerial.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CHOOSE_SERIAL_H
#define CHOOSE_SERIAL_H

#include "GenericPage.h"

#include <QRegExp>

namespace Ui {
    class ChooseSerial;
}

class ChooseSerial : public GenericPage
{
    Q_OBJECT
public:
    explicit ChooseSerial(QWidget *parent = 0);
    ~ChooseSerial();

    void setValues(const QVariantHash &args);
    QVariantHash values() const;
    bool isValid() const;

public slots:
    void load();

private:
    Ui::ChooseSerial *ui;
    QRegExp m_rx;
    bool m_isValid;
};

#endif
